@@ -10,7 +10,6 @@ import contextlib
 import time
 import numpy as np
 import torch
-import pathlib
 import pandas as pd
 import matplotlib
 
@@ -23,19 +22,22 @@ from . import plot as hplt
 
 import git
 
-repo = git.Repo(".", search_parent_directories=True)
-
 
 def _is_loaded(module_name: str) -> bool:
     return module_name in sys.modules
 
 
 # https://stackoverflow.com/questions/14989858/get-the-current-git-hash-in-a-python-script
-def get_current_commit_hash(repo):
+def get_current_commit_hash(default_commit="00000"):
     """Provided a repo return the hash of commit HEAD points to
 
     :param repo: git.Repo
     """
+    try:
+        repo = git.Repo(".", search_parent_directories=True)
+    except:
+        logging.warning("Unable to retrieve commit hash for repo head")
+        return default_commit
     try:
         return repo.head.object.hexsha
     except:
@@ -43,10 +45,7 @@ def get_current_commit_hash(repo):
             return repo.head.commit.hexsha
         except:
             logging.warning("Unable to retrieve commit hash for repo head")
-            return "Hermes was unable to retrieve this information"
-
-
-settings = st.load()
+            return default_commit
 
 
 class Experiment:
@@ -112,9 +111,8 @@ class Experiment:
 
         # get data relevant at start of experiment
         start_time = datetime.now()
-        commit_hash = get_current_commit_hash(
-            repo
-        )  # TODO this should be script specific
+        settings = execution_file.settings
+        commit_hash = get_current_commit_hash()
 
         # check if experiments directory exists, if not make it
         path_to_experiments = Path(settings["path_to_experiments"])
@@ -408,7 +406,6 @@ class Experiment:
             nnf = Path(nnf_string)
             possible_paths = [nnf]
             try:
-                nnf_string_splitted = nnf_string.split(".")
                 nnf_string_short = nnf_string.split(".")[-2] + ".py"
                 possible_paths.append(Path(nnf_string_short))
             except:
@@ -672,7 +669,7 @@ class Experiment:
         dir_list = os.listdir(".")
         for part in dir_list:
             # skip parts of the directory that don't contain the idx
-            if not self.identifier in part:
+            if self.identifier not in part:
                 continue
             self.move_file(part)
 
